import requests
import json
import csv
import os
from datetime import datetime, timedelta

# Define the API endpoint URL
base_url = "https://api.baselinker.com/connector.php"

# Replace 'YOUR_API_TOKEN' with your actual BaseLinker API token
api_token = "1426-10044-8TA3V6MQU7M54479DKBFTXXZR88EJDGBHF8D1XWRP991H8Z4N99ZF9JOKTFX26RI"

csv_file_path = '/Users/filip/Desktop/Shumee/Python/skroutz_orders/order_ids.csv'

save_directory = '/Users/filip/Desktop/Shumee/Python/skroutz_orders/order_jsons/'

# Read order IDs from a CSV file
with open(csv_file_path, mode='r') as file:
    csv_reader = csv.DictReader(file)
    for row in csv_reader:
        order_id = row['order_id']
        
        json_file_path = os.path.join(save_directory, f"{order_id}.json")
        # Load the JSON data from the previously saved file
        with open(json_file_path, "r", encoding="utf-8") as json_file:
            order_data = json.load(json_file)
        
        # Extract relevant information from the JSON
        order = order_data.get("order", {})  # Extract the "order" dictionary or an empty dictionary if it doesn't exist
        phone = order.get("customer", {}).get("mobile", "")  # Extract the "mobile" field or an empty string if it doesn't exist
        shipping_cost = order.get("shipping_cost", 0.0)  # Extract the "shipping_cost" field or 0.0 if it doesn't exist
        skroutz_id = order.get("code")
        created_at = order.get("created_at")

        created_at_datetime = datetime.fromisoformat(created_at[:-6])
        created_at_datetime -= timedelta(seconds=3600)
        created_at_unix = int(created_at_datetime.timestamp())

        # Create the JSON payload for the POST request
        payload = {
            "order_status_id": "78040",
            "date_add": created_at_unix,
            "phone": phone,
            "email": "niemamaila@shumee.pl",
            "currency": "EUR",
            "payment_method_cod": "0",
            "paid": "1",
            "custom_source_id": "7327",
            "delivery_method": "Skroutz",
            "delivery_price": shipping_cost,
            "delivery_fullname": order.get("customer", {}).get("first_name", "") + " " + order.get("customer", {}).get("last_name", ""),
            "delivery_address": order.get("customer", {}).get("address", {}).get("street_name", "") + " " + order.get("customer", {}).get("address", {}).get("street_number", ""),
            "delivery_city": order.get("customer", {}).get("address", {}).get("city", ""),
            "delivery_postcode": order.get("customer", {}).get("address", {}).get("zip", ""),
            "delivery_country_code": order.get("customer", {}).get("address", {}).get("country_code", "GR"),
            "invoice_fullname": order.get("customer", {}).get("first_name", "") + " " + order.get("customer", {}).get("last_name", ""),
            "invoice_address": order.get("customer", {}).get("address", {}).get("street_name", "") + " " + order.get("customer", {}).get("address", {}).get("street_number", ""),
            "invoice_city": order.get("customer", {}).get("address", {}).get("city", ""),
            "invoice_postcode": order.get("customer", {}).get("address", {}).get("zip", ""),
            "invoice_country_code": order.get("customer", {}).get("address", {}).get("country_code", "GR"),
            "want_invoice": "0",
            "custom_extra_fields": {
                "38799": skroutz_id
            },
            "products": [
                {
                    "storage": "shop",
                    "storage_id": 0,
                    "product_id": line_item.get("shop_uid", ""),
                    "name": line_item.get("product_name", ""),
                    "sku": line_item.get("shop_uid", ""),
                    "price_brutto": line_item.get("unit_price", 0.0),
                    "tax_rate": 24,
                    "quantity": line_item.get("quantity", 0),
                    "weight": 0
                }
                for line_item in order.get("line_items", [])
            ]
        }

        
        # Perform the POST request with the API token in the header
        data = {
        'token': api_token,
        'method': 'addOrder',
        'parameters': json.dumps(payload)
        }
        response = requests.post(base_url, data=data)
        
        # Check the response status code
        if response.status_code == 200:
            print(f"Successfully sent POST request for order ID {order_id}")
            print("Response from Baselinker:")
            print(response.text)
        else:
            print(f"Failed to send POST request for order ID {order_id}")
            print(response.text)
